summaryrefslogtreecommitdiff
path: root/sql
diff options
context:
space:
mode:
authorSergey Vojtovich <svoj@mariadb.org>2016-03-07 14:25:02 +0400
committerSergey Vojtovich <svoj@mariadb.org>2016-03-07 14:25:02 +0400
commit3c37f35f05d02d736d551578312f3d3442108fde (patch)
tree931f4a045467951a6ef8833631d6f0aeb04b53c3 /sql
parentf8251911a44f6b65c2377e9945e208e240dfec33 (diff)
parent1777fd5f556a9c68cae01ad2aadaf4865984e649 (diff)
downloadmariadb-git-3c37f35f05d02d736d551578312f3d3442108fde.tar.gz
Merge pull request #159 from ottok/ok-debpkg-10.0
Fix spelling: occurred, execute, which etc
Diffstat (limited to 'sql')
-rw-r--r--sql/event_db_repository.cc2
-rw-r--r--sql/event_queue.cc2
-rw-r--r--sql/ha_ndbcluster.cc2
-rw-r--r--sql/ha_ndbcluster_binlog.cc2
-rw-r--r--sql/ha_partition.cc2
-rw-r--r--sql/handler.cc2
-rw-r--r--sql/handler.h2
-rw-r--r--sql/item.cc4
-rw-r--r--sql/item.h4
-rw-r--r--sql/item_func.cc4
-rw-r--r--sql/item_subselect.cc2
-rw-r--r--sql/log.cc14
-rw-r--r--sql/log_event.cc4
-rw-r--r--sql/log_event_old.cc4
-rw-r--r--sql/my_apc.cc2
-rw-r--r--sql/rpl_parallel.cc6
-rw-r--r--sql/rpl_parallel.h2
-rw-r--r--sql/share/errmsg-utf8.txt2
-rw-r--r--sql/signal_handler.cc2
-rw-r--r--sql/sp_head.h2
-rw-r--r--sql/sql_acl.cc2
-rw-r--r--sql/sql_base.cc10
-rw-r--r--sql/sql_join_cache.cc2
-rw-r--r--sql/sql_lex.h2
-rw-r--r--sql/sql_parse.cc2
-rw-r--r--sql/sql_prepare.cc2
-rw-r--r--sql/sql_repl.cc4
-rw-r--r--sql/sql_select.cc8
-rw-r--r--sql/sql_select.h2
-rw-r--r--sql/sql_show.cc4
-rw-r--r--sql/sql_string.cc4
-rw-r--r--sql/sql_trigger.cc2
-rw-r--r--sql/sql_update.cc2
-rw-r--r--sql/sql_view.cc4
-rw-r--r--sql/threadpool_win.cc4
-rw-r--r--sql/tztime.cc8
36 files changed, 64 insertions, 64 deletions
diff --git a/sql/event_db_repository.cc b/sql/event_db_repository.cc
index 30dffc30edd..6785b46d0da 100644
--- a/sql/event_db_repository.cc
+++ b/sql/event_db_repository.cc
@@ -938,7 +938,7 @@ end:
@retval FALSE an event with such db/name key exists
- @retval TRUE no record found or an error occured.
+ @retval TRUE no record found or an error occurred.
*/
bool
diff --git a/sql/event_queue.cc b/sql/event_queue.cc
index 35187af23ac..ae8ba258717 100644
--- a/sql/event_queue.cc
+++ b/sql/event_queue.cc
@@ -191,7 +191,7 @@ Event_queue::deinit_queue()
@param[out] created set to TRUE if no error and the element is
added to the queue, FALSE otherwise
- @retval TRUE an error occured. The value of created is undefined,
+ @retval TRUE an error occurred. The value of created is undefined,
the element was not deleted.
@retval FALSE success
*/
diff --git a/sql/ha_ndbcluster.cc b/sql/ha_ndbcluster.cc
index ed05521a473..1daf7f9b944 100644
--- a/sql/ha_ndbcluster.cc
+++ b/sql/ha_ndbcluster.cc
@@ -8123,7 +8123,7 @@ uint8 ha_ndbcluster::table_cache_type()
@param[out] commit_count Commit count for the table.
@return 0 on success.
- @return 1 if an error occured.
+ @return 1 if an error occurred.
*/
uint ndb_get_commitcount(THD *thd, char *norm_name,
diff --git a/sql/ha_ndbcluster_binlog.cc b/sql/ha_ndbcluster_binlog.cc
index 64ae31ce231..6ee8fde3e42 100644
--- a/sql/ha_ndbcluster_binlog.cc
+++ b/sql/ha_ndbcluster_binlog.cc
@@ -3875,7 +3875,7 @@ restart:
else if (ndb_latest_applied_binlog_epoch > 0)
{
sql_print_warning("NDB Binlog: cluster has reconnected. "
- "Changes to the database that occured while "
+ "Changes to the database that occurred while "
"disconnected will not be in the binlog");
}
if (opt_ndb_extra_logging)
diff --git a/sql/ha_partition.cc b/sql/ha_partition.cc
index e59954e13c2..69cc78588a8 100644
--- a/sql/ha_partition.cc
+++ b/sql/ha_partition.cc
@@ -8307,7 +8307,7 @@ bool ha_partition::inplace_alter_table(TABLE *altered_table,
/*
Note that this function will try rollback failed ADD INDEX by
executing DROP INDEX for the indexes that were committed (if any)
- before the error occured. This means that the underlying storage
+ before the error occurred. This means that the underlying storage
engine must be able to drop index in-place with X-lock held.
(As X-lock will be held here if new indexes are to be committed)
*/
diff --git a/sql/handler.cc b/sql/handler.cc
index 51a608304aa..9b217c60100 100644
--- a/sql/handler.cc
+++ b/sql/handler.cc
@@ -313,7 +313,7 @@ int ha_init_errors(void)
/* Set the dedicated error messages. */
SETMSG(HA_ERR_KEY_NOT_FOUND, ER_DEFAULT(ER_KEY_NOT_FOUND));
SETMSG(HA_ERR_FOUND_DUPP_KEY, ER_DEFAULT(ER_DUP_KEY));
- SETMSG(HA_ERR_RECORD_CHANGED, "Update wich is recoverable");
+ SETMSG(HA_ERR_RECORD_CHANGED, "Update which is recoverable");
SETMSG(HA_ERR_WRONG_INDEX, "Wrong index given to function");
SETMSG(HA_ERR_CRASHED, ER_DEFAULT(ER_NOT_KEYFILE));
SETMSG(HA_ERR_WRONG_IN_RECORD, ER_DEFAULT(ER_CRASHED_ON_USAGE));
diff --git a/sql/handler.h b/sql/handler.h
index 2e219d5f3cc..e3dcf4fa63a 100644
--- a/sql/handler.h
+++ b/sql/handler.h
@@ -3502,7 +3502,7 @@ public:
*) a) If the previous step succeeds, handler::ha_commit_inplace_alter_table() is
called to allow the storage engine to do any final updates to its structures,
to make all earlier changes durable and visible to other connections.
- b) If we have failed to upgrade lock or any errors have occured during the
+ b) If we have failed to upgrade lock or any errors have occurred during the
handler functions calls (including commit), we call
handler::ha_commit_inplace_alter_table()
to rollback all changes which were done during previous steps.
diff --git a/sql/item.cc b/sql/item.cc
index bed8824f68f..d9d1409572c 100644
--- a/sql/item.cc
+++ b/sql/item.cc
@@ -4752,7 +4752,7 @@ bool is_outer_table(TABLE_LIST *table, SELECT_LEX *select)
@retval
0 column fully fixed and fix_fields() should return FALSE
@retval
- -1 error occured
+ -1 error occurred
*/
int
@@ -6703,7 +6703,7 @@ void Item_field::update_null_value()
UPDATE statement.
RETURN
- 0 if error occured
+ 0 if error occurred
ref if all conditions are met
this field otherwise
*/
diff --git a/sql/item.h b/sql/item.h
index 4347bdb6c07..b45faaf45ce 100644
--- a/sql/item.h
+++ b/sql/item.h
@@ -523,7 +523,7 @@ public:
RETURN
FALSE if parameter value has been set,
- TRUE if error has occured.
+ TRUE if error has occurred.
*/
virtual bool set_value(THD *thd, sp_rcontext *ctx, Item **it)= 0;
@@ -2513,7 +2513,7 @@ public:
/*
If value for parameter was not set we treat it as non-const
- so noone will use parameters value in fix_fields still
+ so no one will use parameters value in fix_fields still
parameter is constant during execution.
*/
virtual table_map used_tables() const
diff --git a/sql/item_subselect.cc b/sql/item_subselect.cc
index 7d361263548..5070fc5a646 100644
--- a/sql/item_subselect.cc
+++ b/sql/item_subselect.cc
@@ -5854,7 +5854,7 @@ int subselect_partial_match_engine::exec()
/* Search for a complete match. */
if ((lookup_res= lookup_engine->index_lookup()))
{
- /* An error occured during lookup(). */
+ /* An error occurred during lookup(). */
item_in->value= 0;
item_in->null_value= 0;
return lookup_res;
diff --git a/sql/log.cc b/sql/log.cc
index f8c9b6991cd..efc3b120437 100644
--- a/sql/log.cc
+++ b/sql/log.cc
@@ -628,7 +628,7 @@ void Log_to_csv_event_handler::cleanup()
indicated in the return value.
@retval FALSE OK
- @retval TRUE error occured
+ @retval TRUE error occurred
*/
bool Log_to_csv_event_handler::
@@ -793,7 +793,7 @@ err:
RETURN
FALSE - OK
- TRUE - error occured
+ TRUE - error occurred
*/
bool Log_to_csv_event_handler::
@@ -1098,7 +1098,7 @@ void Log_to_file_event_handler::flush()
RETURN
FALSE - OK
- TRUE - error occured
+ TRUE - error occurred
*/
bool LOGGER::error_log_print(enum loglevel level, const char *format,
@@ -1256,7 +1256,7 @@ bool LOGGER::flush_general_log()
RETURN
FALSE OK
- TRUE error occured
+ TRUE error occurred
*/
bool LOGGER::slow_log_print(THD *thd, const char *query, uint query_length,
@@ -2752,7 +2752,7 @@ void MYSQL_QUERY_LOG::reopen_file()
RETURN
FASE - OK
- TRUE - error occured
+ TRUE - error occurred
*/
bool MYSQL_QUERY_LOG::write(time_t event_time, const char *user_host,
@@ -2854,7 +2854,7 @@ err:
RETURN
FALSE - OK
- TRUE - error occured
+ TRUE - error occurred
*/
bool MYSQL_QUERY_LOG::write(THD *thd, time_t current_time,
@@ -6130,7 +6130,7 @@ binlog_checkpoint_callback(void *cookie)
/*
For every supporting engine, we increment the xid_count and issue a
commit_checkpoint_request(). Then we can count when all
- commit_checkpoint_notify() callbacks have occured, and then log a new
+ commit_checkpoint_notify() callbacks have occurred, and then log a new
binlog checkpoint event.
*/
mysql_bin_log.mark_xids_active(entry->binlog_id, 1);
diff --git a/sql/log_event.cc b/sql/log_event.cc
index 40da25dd62f..30634c4e73b 100644
--- a/sql/log_event.cc
+++ b/sql/log_event.cc
@@ -1348,9 +1348,9 @@ int Log_event::read_log_event(IO_CACHE* file, String* packet,
if (packet->append(file, data_len))
{
/*
- Fatal error occured when appending rest of the event
+ Fatal error occurred when appending rest of the event
to packet, possible failures:
- 1. EOF occured when reading from file, it's really an error
+ 1. EOF occurred when reading from file, it's really an error
as data_len is >=0 there's supposed to be more bytes available.
file->error will have been set to number of bytes left to read
2. Read was interrupted, file->error would normally be set to -1
diff --git a/sql/log_event_old.cc b/sql/log_event_old.cc
index e6c05aeb849..ad68275a274 100644
--- a/sql/log_event_old.cc
+++ b/sql/log_event_old.cc
@@ -249,7 +249,7 @@ Old_rows_log_event::do_apply_event(Old_rows_log_event *ev, rpl_group_info *rgi)
}
if (error)
- { /* error has occured during the transaction */
+ { /* error has occurred during the transaction */
rli->report(ERROR_LEVEL, ev_thd->get_stmt_da()->sql_errno(), NULL,
"Error in %s event: error during transaction execution "
"on table %s.%s. %s",
@@ -1690,7 +1690,7 @@ int Old_rows_log_event::do_apply_event(rpl_group_info *rgi)
} // if (table)
if (error)
- { /* error has occured during the transaction */
+ { /* error has occurred during the transaction */
rli->report(ERROR_LEVEL, thd->net.last_errno, NULL,
"Error in %s event: error during transaction execution "
"on table %s.%s. %s",
diff --git a/sql/my_apc.cc b/sql/my_apc.cc
index 17660688be0..0b9fe9899b9 100644
--- a/sql/my_apc.cc
+++ b/sql/my_apc.cc
@@ -158,7 +158,7 @@ void init_show_explain_psi_keys(void)
@retval FALSE - Ok, the call has been made
@retval TRUE - Call wasnt made (either the target is in disabled state or
- timeout occured)
+ timeout occurred)
*/
bool Apc_target::make_apc_call(THD *caller_thd, Apc_call *call,
diff --git a/sql/rpl_parallel.cc b/sql/rpl_parallel.cc
index b2e957a3e6e..98712f18c1b 100644
--- a/sql/rpl_parallel.cc
+++ b/sql/rpl_parallel.cc
@@ -698,7 +698,7 @@ do_retry:
thd->clear_error();
/*
- If we retry due to a deadlock kill that occured during the commit step, we
+ If we retry due to a deadlock kill that occurred during the commit step, we
might have already updated (but not committed) an update of table
mysql.gtid_slave_pos, and cleared the gtid_pending flag. Now we have
rolled back any such update, so we must set the gtid_pending flag back to
@@ -1100,7 +1100,7 @@ handle_rpl_parallel_thread(void *arg)
/*
Register ourself to wait for the previous commit, if we need to do
such registration _and_ that previous commit has not already
- occured.
+ occurred.
*/
register_wait_for_prior_event_group_commit(rgi, entry);
@@ -1149,7 +1149,7 @@ handle_rpl_parallel_thread(void *arg)
{
/*
Do an extra check for (deadlock) kill here. This helps prevent a
- lingering deadlock kill that occured during normal DML processing to
+ lingering deadlock kill that occurred during normal DML processing to
propagate past the mark_start_commit(). If we detect a deadlock only
after mark_start_commit(), we have to unmark, which has at least a
theoretical possibility of leaving a window where it looks like all
diff --git a/sql/rpl_parallel.h b/sql/rpl_parallel.h
index 3012daa8763..a02c1af3b3e 100644
--- a/sql/rpl_parallel.h
+++ b/sql/rpl_parallel.h
@@ -296,7 +296,7 @@ struct rpl_parallel_entry {
group here. Then later event groups (with higher sub_id) can know not to
try to start (event groups that already started will be rolled back when
wait_for_prior_commit() returns error).
- The value is ULONGLONG_MAX when no error occured.
+ The value is ULONGLONG_MAX when no error occurred.
*/
uint64 stop_on_error_sub_id;
/*
diff --git a/sql/share/errmsg-utf8.txt b/sql/share/errmsg-utf8.txt
index 4394e796a1a..627f54631a3 100644
--- a/sql/share/errmsg-utf8.txt
+++ b/sql/share/errmsg-utf8.txt
@@ -6035,7 +6035,7 @@ ER_EVENT_CANNOT_ALTER_IN_THE_PAST
eng "Event execution time is in the past and ON COMPLETION NOT PRESERVE is set. The event was not changed. Specify a time in the future."
ger "Execution Zeitpunkt des Ereignisses in der Vergangenheit liegt, und es war NACH ABSCHLUSS Set nicht erhalten. Die Veranstaltung wurde nicht verändert. Geben Sie einen Zeitpunkt in der Zukunft."
ER_SLAVE_INCIDENT
- eng "The incident %s occured on the master. Message: %-.64s"
+ eng "The incident %s occurred on the master. Message: %-.64s"
ger "Der Vorfall %s passierte auf dem Master. Meldung: %-.64s"
ER_NO_PARTITION_FOR_GIVEN_VALUE_SILENT
eng "Table has no partition for some existing values"
diff --git a/sql/signal_handler.cc b/sql/signal_handler.cc
index 3fadbcd088f..4591d379777 100644
--- a/sql/signal_handler.cc
+++ b/sql/signal_handler.cc
@@ -216,7 +216,7 @@ extern "C" sig_handler handle_fatal_signal(int sig)
if (calling_initgroups)
{
my_safe_printf_stderr("%s", "\n"
- "This crash occured while the server was calling initgroups(). This is\n"
+ "This crash occurred while the server was calling initgroups(). This is\n"
"often due to the use of a mysqld that is statically linked against \n"
"glibc and configured to use LDAP in /etc/nsswitch.conf.\n"
"You will need to either upgrade to a version of glibc that does not\n"
diff --git a/sql/sp_head.h b/sql/sp_head.h
index dbdb957aa79..71a64d9a5af 100644
--- a/sql/sp_head.h
+++ b/sql/sp_head.h
@@ -608,7 +608,7 @@ public:
instruction for CONTINUE error handlers.
@retval 0 on success,
- @retval other if some error occured
+ @retval other if some error occurred
*/
virtual int execute(THD *thd, uint *nextp) = 0;
diff --git a/sql/sql_acl.cc b/sql/sql_acl.cc
index 63d7d7a0399..a70afe4fca9 100644
--- a/sql/sql_acl.cc
+++ b/sql/sql_acl.cc
@@ -9895,7 +9895,7 @@ bool sp_revoke_privileges(THD *thd, const char *sp_db, const char *sp_name,
@return
@retval FALSE Success
- @retval TRUE An error occured. Error message not yet sent.
+ @retval TRUE An error occurred. Error message not yet sent.
*/
bool sp_grant_privileges(THD *thd, const char *sp_db, const char *sp_name,
diff --git a/sql/sql_base.cc b/sql/sql_base.cc
index 01878d57b13..fc1d716667e 100644
--- a/sql/sql_base.cc
+++ b/sql/sql_base.cc
@@ -8531,7 +8531,7 @@ bool setup_on_expr(THD *thd, TABLE_LIST *table, bool is_update)
TODO
RETURN
- TRUE if some error occured (e.g. out of memory)
+ TRUE if some error occurred (e.g. out of memory)
FALSE if all is OK
*/
@@ -8641,7 +8641,7 @@ err_no_arena:
function.
@return Status
- @retval true An error occured.
+ @retval true An error occurred.
@retval false OK.
*/
@@ -8749,7 +8749,7 @@ err:
record[1] buffers correspond to new and old versions of row respectively.
@return Status
- @retval true An error occured.
+ @retval true An error occurred.
@retval false OK.
*/
@@ -8805,7 +8805,7 @@ fill_record_n_invoke_before_triggers(THD *thd, TABLE *table, List<Item> &fields,
function.
@return Status
- @retval true An error occured.
+ @retval true An error occurred.
@retval false OK.
*/
@@ -8897,7 +8897,7 @@ err:
record[1] buffers correspond to new and old versions of row respectively.
@return Status
- @retval true An error occured.
+ @retval true An error occurred.
@retval false OK.
*/
diff --git a/sql/sql_join_cache.cc b/sql/sql_join_cache.cc
index 254b7026e96..f701c424f63 100644
--- a/sql/sql_join_cache.cc
+++ b/sql/sql_join_cache.cc
@@ -2206,7 +2206,7 @@ finish:
for a match for any record from join_tab. To iterate over the candidates
for a match the virtual function get_next_candidate_for_match is used,
while the virtual function prepare_look_for_matches is called to prepare
- for such iteration proccess.
+ for such iteration process.
NOTES
The function produces all matching extensions for the records in the
diff --git a/sql/sql_lex.h b/sql/sql_lex.h
index 6ba384e93a0..019231e2004 100644
--- a/sql/sql_lex.h
+++ b/sql/sql_lex.h
@@ -590,7 +590,7 @@ public:
global parameters for union
*/
st_select_lex *global_parameters;
- //node on wich we should return current_select pointer after parsing subquery
+ //node on which we should return current_select pointer after parsing subquery
st_select_lex *return_to;
/* LIMIT clause runtime counters */
ha_rows select_limit_cnt, offset_limit_cnt;
diff --git a/sql/sql_parse.cc b/sql/sql_parse.cc
index 8373ddabe3c..d2fed787ba9 100644
--- a/sql/sql_parse.cc
+++ b/sql/sql_parse.cc
@@ -7306,7 +7306,7 @@ bool st_select_lex_unit::add_fake_select_lex(THD *thd_arg)
@retval
FALSE if all is OK
@retval
- TRUE if a memory allocation error occured
+ TRUE if a memory allocation error occurred
*/
bool
diff --git a/sql/sql_prepare.cc b/sql/sql_prepare.cc
index ec7cdc4852b..5fe30f21b32 100644
--- a/sql/sql_prepare.cc
+++ b/sql/sql_prepare.cc
@@ -1820,7 +1820,7 @@ static bool mysql_test_create_table(Prepared_statement *stmt)
@note This function handles create view commands.
@retval FALSE Operation was a success.
- @retval TRUE An error occured.
+ @retval TRUE An error occurred.
*/
static bool mysql_test_create_view(Prepared_statement *stmt)
diff --git a/sql/sql_repl.cc b/sql/sql_repl.cc
index cceab00ac60..4505ad69880 100644
--- a/sql/sql_repl.cc
+++ b/sql/sql_repl.cc
@@ -3078,7 +3078,7 @@ int reset_slave(THD *thd, Master_info* mi)
char fname[FN_REFLEN];
int thread_mask= 0, error= 0;
uint sql_errno=ER_UNKNOWN_ERROR;
- const char* errmsg= "Unknown error occured while reseting slave";
+ const char* errmsg= "Unknown error occurred while reseting slave";
char master_info_file_tmp[FN_REFLEN];
char relay_log_info_file_tmp[FN_REFLEN];
DBUG_ENTER("reset_slave");
@@ -3660,7 +3660,7 @@ bool mysql_show_binlog_events(THD* thd)
DBUG_ASSERT(thd->lex->sql_command == SQLCOM_SHOW_BINLOG_EVENTS ||
thd->lex->sql_command == SQLCOM_SHOW_RELAYLOG_EVENTS);
- /* select wich binary log to use: binlog or relay */
+ /* select which binary log to use: binlog or relay */
if ( thd->lex->sql_command == SQLCOM_SHOW_BINLOG_EVENTS )
{
/*
diff --git a/sql/sql_select.h b/sql/sql_select.h
index 18a649bc47a..cbad287c5e5 100644
--- a/sql/sql_select.h
+++ b/sql/sql_select.h
@@ -908,7 +908,7 @@ protected:
enum enum_reopt_result {
REOPT_NEW_PLAN, /* there is a new reoptimized plan */
REOPT_OLD_PLAN, /* no new improved plan can be found, use the old one */
- REOPT_ERROR, /* an irrecovarable error occured during reoptimization */
+ REOPT_ERROR, /* an irrecovarable error occurred during reoptimization */
REOPT_NONE /* not yet reoptimized */
};
diff --git a/sql/sql_show.cc b/sql/sql_show.cc
index f4c2424f65d..b8926b986b0 100644
--- a/sql/sql_show.cc
+++ b/sql/sql_show.cc
@@ -4448,7 +4448,7 @@ uint get_table_open_method(TABLE_LIST *tables,
@retval FALSE No error, if lock was obtained TABLE_LIST::mdl_request::ticket
is set to non-NULL value.
- @retval TRUE Some error occured (probably thread was killed).
+ @retval TRUE Some error occurred (probably thread was killed).
*/
static bool
@@ -4556,7 +4556,7 @@ static int fill_schema_table_from_frm(THD *thd, TABLE_LIST *tables,
if (try_acquire_high_prio_shared_mdl_lock(thd, &table_list, can_deadlock))
{
/*
- Some error occured (most probably we have been killed while
+ Some error occurred (most probably we have been killed while
waiting for conflicting locks to go away), let the caller to
handle the situation.
*/
diff --git a/sql/sql_string.cc b/sql/sql_string.cc
index a7bfa6c1455..b94bd6a0175 100644
--- a/sql/sql_string.cc
+++ b/sql/sql_string.cc
@@ -76,9 +76,9 @@ bool String::real_alloc(uint32 length)
@retval false Either the copy operation is complete or, if the size of the
new buffer is smaller than the currently allocated buffer (if one exists),
- no allocation occured.
+ no allocation occurred.
- @retval true An error occured when attempting to allocate memory.
+ @retval true An error occurred when attempting to allocate memory.
*/
bool String::realloc_raw(uint32 alloc_length)
{
diff --git a/sql/sql_trigger.cc b/sql/sql_trigger.cc
index a59bbb5bc61..198f414eb85 100644
--- a/sql/sql_trigger.cc
+++ b/sql/sql_trigger.cc
@@ -2232,7 +2232,7 @@ void Table_triggers_list::mark_fields_used(trg_event_type event)
/**
- Signals to the Table_triggers_list that a parse error has occured when
+ Signals to the Table_triggers_list that a parse error has occurred when
reading a trigger from file. This makes the Table_triggers_list enter an
error state flagged by m_has_unparseable_trigger == true. The error message
will be used whenever a statement invoking or manipulating triggers is
diff --git a/sql/sql_update.cc b/sql/sql_update.cc
index 1220c39cf85..a59e635afaa 100644
--- a/sql/sql_update.cc
+++ b/sql/sql_update.cc
@@ -2552,7 +2552,7 @@ bool multi_update::send_eof()
if (local_error > 0) // if the above log write did not fail ...
{
/* Safety: If we haven't got an error before (can happen in do_updates) */
- my_message(ER_UNKNOWN_ERROR, "An error occured in multi-table update",
+ my_message(ER_UNKNOWN_ERROR, "An error occurred in multi-table update",
MYF(0));
DBUG_RETURN(TRUE);
}
diff --git a/sql/sql_view.cc b/sql/sql_view.cc
index 0d88b3a1eda..f3717e3ded2 100644
--- a/sql/sql_view.cc
+++ b/sql/sql_view.cc
@@ -245,7 +245,7 @@ fill_defined_view_parts (THD *thd, TABLE_LIST *view)
@param mode VIEW_CREATE_NEW, VIEW_ALTER, VIEW_CREATE_OR_REPLACE
@retval FALSE Operation was a success.
- @retval TRUE An error occured.
+ @retval TRUE An error occurred.
*/
bool create_view_precheck(THD *thd, TABLE_LIST *tables, TABLE_LIST *view,
@@ -388,7 +388,7 @@ bool create_view_precheck(THD *thd, TABLE_LIST *tables, TABLE_LIST *view,
@note This function handles both create and alter view commands.
@retval FALSE Operation was a success.
- @retval TRUE An error occured.
+ @retval TRUE An error occurred.
*/
bool mysql_create_view(THD *thd, TABLE_LIST *views,
diff --git a/sql/threadpool_win.cc b/sql/threadpool_win.cc
index 4be51f3d6e9..8ae3252caa3 100644
--- a/sql/threadpool_win.cc
+++ b/sql/threadpool_win.cc
@@ -388,7 +388,7 @@ int start_io(connection_t *connection, PTP_CALLBACK_INSTANCE instance)
return 0;
}
- /* Some error occured */
+ /* Some error occurred */
CancelThreadpoolIo(io);
return -1;
}
@@ -575,7 +575,7 @@ static VOID CALLBACK io_completion_callback(PTP_CALLBACK_INSTANCE instance,
return;
error:
- /* Some error has occured. */
+ /* Some error has occurred. */
destroy_connection(connection, instance);
free(connection);
diff --git a/sql/tztime.cc b/sql/tztime.cc
index 9791e218108..75b732f4436 100644
--- a/sql/tztime.cc
+++ b/sql/tztime.cc
@@ -309,7 +309,7 @@ tz_load(const char *name, TIME_ZONE_INFO *sp, MEM_ROOT *storage)
Note: See description of TIME_to_gmt_sec() function first.
In order to perform MYSQL_TIME -> my_time_t conversion we need to build table
which defines "shifted by tz offset and leap seconds my_time_t" ->
- my_time_t function wich is almost the same (except ranges of ambiguity)
+ my_time_t function which is almost the same (except ranges of ambiguity)
as reverse function to piecewise linear function used for my_time_t ->
"shifted my_time_t" conversion and which is also specified as table in
zoneinfo file or in our db (It is specified as start of time type ranges
@@ -614,7 +614,7 @@ sec_to_TIME(MYSQL_TIME * tmp, my_time_t t, long offset)
/*
- Find time range wich contains given my_time_t value
+ Find time range which contains given my_time_t value
SYNOPSIS
find_time_range()
@@ -710,7 +710,7 @@ find_transition_type(my_time_t t, const TIME_ZONE_INFO *sp)
TODO
We can improve this function by creating joined array of transitions and
leap corrections. This will require adding extra field to TRAN_TYPE_INFO
- for storing number of "extra" seconds to minute occured due to correction
+ for storing number of "extra" seconds to minute occurred due to correction
(60th and 61st second, look how we calculate them as "hit" in this
function).
Under realistic assumptions about frequency of transitions the same array
@@ -2763,7 +2763,7 @@ main(int argc, char **argv)
#ifdef TESTTIME
/*
- Some simple brute-force test wich allowed to catch a pair of bugs.
+ Some simple brute-force test which allowed to catch a pair of bugs.
Also can provide interesting facts about system's time zone support
implementation.
*/
diff --git a/sql/item_func.cc b/sql/item_func.cc
index f597bf73617..6c205b6afa7 100644
--- a/sql/item_func.cc
+++ b/sql/item_func.cc
@@ -227,7 +227,7 @@ Item_func::fix_fields(THD *thd, Item **ref)
}
}
fix_length_and_dec();
- if (thd->is_error()) // An error inside fix_length_and_dec occured
+ if (thd->is_error()) // An error inside fix_length_and_dec occurred
return TRUE;
fixed= 1;
return FALSE;
@@ -5639,7 +5639,7 @@ void Item_func_get_user_var::fix_length_and_dec()
/*
If the variable didn't exist it has been created as a STRING-type.
- 'var_entry' is NULL only if there occured an error during the call to
+ 'var_entry' is NULL only if there occurred an error during the call to
get_var_with_binlog.
*/
if (!error && var_entry)
diff --git a/sql/sql_select.cc b/sql/sql_select.cc
index 514ba947172..28f59047b43 100644
--- a/sql/sql_select.cc
+++ b/sql/sql_select.cc
@@ -443,7 +443,7 @@ bool handle_select(THD *thd, LEX *lex, select_result *result,
this field from inner subqueries.
@return Status
- @retval true An error occured.
+ @retval true An error occurred.
@retval false OK.
*/
@@ -12702,7 +12702,7 @@ static bool check_equality(THD *thd, Item *item, COND_EQUAL *cond_equal,
equality predicates that is equivalent to the conjunction.
Thus, =(a1,a2,a3) can substitute for ((a1=a3) AND (a2=a3) AND (a2=a1)) as
it is equivalent to ((a1=a2) AND (a2=a3)).
- The function always makes a substitution of all equality predicates occured
+ The function always makes a substitution of all equality predicates occurred
in a conjuction for a minimal set of multiple equality predicates.
This set can be considered as a canonical representation of the
sub-conjunction of the equality predicates.
@@ -21380,7 +21380,7 @@ find_order_in_list(THD *thd, Item **ref_pointer_array, TABLE_LIST *tables,
select_item= find_item_in_list(order_item, fields, &counter,
REPORT_EXCEPT_NOT_FOUND, &resolution);
if (!select_item)
- return TRUE; /* The item is not unique, or some other error occured. */
+ return TRUE; /* The item is not unique, or some other error occurred. */
/* Check whether the resolved field is not ambiguos. */
@@ -24736,7 +24736,7 @@ void JOIN::restore_query_plan(Join_plan_state *restore_from)
@retval REOPT_NEW_PLAN there is a new plan.
@retval REOPT_OLD_PLAN no new improved plan was produced, use the old one.
- @retval REOPT_ERROR an irrecovarable error occured during reoptimization.
+ @retval REOPT_ERROR an irrecovarable error occurred during reoptimization.
*/
JOIN::enum_reopt_result